@@ -1,24 +1,53 @@
 """
 Base class for all collector plugins
 """
+
 import json
-import os
+
 from abc import abstractmethod
-from typing import Any, List, Optional, final
+from pathlib import Path
+from typing import Any, List, Optional, Union, final
 
 from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
 
-from hoppr import plugin_utils
+from hoppr import __version__, plugin_utils
 from hoppr.base_plugins.hoppr import HopprPlugin, hoppr_process, hoppr_rerunner
 from hoppr.configs.credentials import Credentials
 from hoppr.hoppr_types.cred_object import CredObject
+from hoppr.hoppr_types.purl_type import PurlType
 from hoppr.result import Result
 from hoppr.utils import dedup_list, remove_empty
 
 
-class CollectorPlugin(HopprPlugin):
+class BaseCollectorPlugin(HopprPlugin):
     """
-    Base class for all collector plugins
+    Base class for collector plugins
+    """
+
+    def directory_for(
+        self,
+        purl_type: Union[str, PurlType],
+        repo_url: str,
+        subdir: Optional[str] = None,
+    ) -> Path:
+        """
+        Identify the directory into which the artifact should be copied
+        """
+
+        repo_dir = plugin_utils.dir_name_from_repo_url(repo_url)
+        directory = Path(self.context.collect_root_dir, str(purl_type), repo_dir)
+
+        if subdir is not None:
+            directory = Path(directory, subdir)
+
+        directory.mkdir(parents=True, exist_ok=True)
+
+        return directory
+
+
+class SerialCollectorPlugin(BaseCollectorPlugin):
+    """
+    Base class for multi-process collector plugins
     """
 
     @staticmethod
@@ -43,20 +72,6 @@ class CollectorPlugin(HopprPlugin):
         This method should attempt to collect a single component from the specified URL
         """
 
-    def directory_for(
-        self, purl_type: str, repo_url: str, subdir: Optional[str] = None
-    ) -> str:
-        """
-        Identify the directory into which the artifact should be copied
-        """
-
-        repo_dir = plugin_utils.dir_name_from_repo_url(repo_url)
-        directory = os.path.join(self.context.collect_root_dir, purl_type, repo_dir)
-        if subdir is not None:
-            directory = os.path.join(directory, subdir)
-        os.makedirs(directory, exist_ok=True)
-        return directory
-
     @final
     @hoppr_process
     def process_component(self, comp: Component) -> Result:
@@ -85,7 +100,43 @@ class CollectorPlugin(HopprPlugin):
     @hoppr_process
     def post_stage_process(self):
         for purl_type in self.supported_purl_types:
-            directory = os.path.join(self.context.collect_root_dir, purl_type)
-            if os.path.isdir(directory):
+            directory = Path(self.context.collect_root_dir, purl_type)
+
+            if directory.is_dir():
                 remove_empty(directory)
+
         return Result.success()
+
+
+class BatchCollectorPlugin(BaseCollectorPlugin):
+    """
+    Base class for single-process collector plugins
+    """
+
+    config_file: Path
+
+    @abstractmethod
+    @hoppr_rerunner
+    def collect(self, comp: Component):
+        """
+        This method should attempt to collect all components
+        from all manifest repositories or registries that were
+        previously configured in the pre stage process.
+
+        Use of a single batch operation (i.e. dynamically constructed
+        shell command) is encouraged if supported by the underlying
+        collection tool(s).
+        """
+
+    @final
+    @hoppr_process
+    def process_component(self, comp: Component) -> Result:
+        """
+        Copy a component to the local collection directory structure
+
+        A CollectorPlugin will never return a RETRY result, but handles the retry logic internally.
+        """
+        logger = self.get_logger()
+        logger.info(f"Processing component {comp.purl}")
+
+        return self.collect(comp)
