@@ -1,22 +1,24 @@
 """
 Collector plugin for git repositories
 """
+
 import os
 import pathlib
 import re
+
 from typing import Any, Dict, Optional
 
 from packageurl import PackageURL  # type: ignore
 
 from hoppr import __version__
-from hoppr.base_plugins.collector import CollectorPlugin
+from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.context import Context
 from hoppr.hoppr_types.cred_object import CredObject
 from hoppr.result import Result
 
 
-class CollectGitPlugin(CollectorPlugin):
+class CollectGitPlugin(SerialCollectorPlugin):
     """
     Class to copy git repositories
     """
