@@ -1,20 +1,22 @@
 """
 Collector plugin for helm charts
 """
+
 import os
+
 from typing import Any, Dict, Optional
 
 from packageurl import PackageURL  # type: ignore
 
 from hoppr import __version__
-from hoppr.base_plugins.collector import CollectorPlugin
+from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.context import Context
 from hoppr.hoppr_types.cred_object import CredObject
 from hoppr.result import Result
 
 
-class CollectHelmPlugin(CollectorPlugin):
+class CollectHelmPlugin(SerialCollectorPlugin):
     """
     Class to copy helm charts
     """
@@ -54,8 +56,8 @@ class CollectHelmPlugin(CollectorPlugin):
                 "fetch",
                 "--repo",
                 source_url,
-                "-d",
-                target_dir,
+                "--destination",
+                f"{target_dir}",
                 purl.name,
                 "--version",
                 purl.version,
