@@ -1,13 +1,14 @@
 """
 Collector plugin for maven artifacts
 """
+
 from tempfile import NamedTemporaryFile
 from typing import Any, Dict, Optional
 
 from packageurl import PackageURL  # type: ignore
 
 from hoppr import __version__
-from hoppr.base_plugins.collector import CollectorPlugin
+from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.context import Context
 from hoppr.hoppr_types.cred_object import CredObject
@@ -17,7 +18,7 @@ _DEFAULT_MAVEN_EXT = "tar.gz"
 _MAVEN_DEP_PLUGIN = "org.apache.maven.plugins:maven-dependency-plugin:2.5.1"
 
 
-class CollectMavenPlugin(CollectorPlugin):
+class CollectMavenPlugin(SerialCollectorPlugin):
     """
     Collector plugin for maven artifacts
     """
