@@ -1,20 +1,22 @@
 """
 Collector plugin for pypi images
 """
+
 import os
+
 from typing import Any, Dict, Optional
 
 from packageurl import PackageURL  # type: ignore
 
 from hoppr import __version__
-from hoppr.base_plugins.collector import CollectorPlugin
+from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.context import Context
 from hoppr.hoppr_types.cred_object import CredObject
 from hoppr.result import Result
 
 
-class CollectPypiPlugin(CollectorPlugin):
+class CollectPypiPlugin(SerialCollectorPlugin):
     """
     Collector plugin for pypi images
     """
@@ -62,7 +64,7 @@ class CollectPypiPlugin(CollectorPlugin):
             "--index-url",
             source_url,
             "-d",
-            target_dir,
+            f"{target_dir}",
             "--no-cache",
             "--timeout",
             "60",
