@@ -1,13 +1,14 @@
 """
-Collector plugin for docker images
+Collector plugin for Yum packages
 """
+
 from pathlib import Path
 from typing import Any, Dict, Optional
 
 from packageurl import PackageURL  # type: ignore
 
 from hoppr import __version__
-from hoppr.base_plugins.collector import CollectorPlugin
+from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.context import Context
 from hoppr.result import Result
@@ -26,7 +27,7 @@ def _artifact_string(purl):
     return artifact_string
 
 
-class CollectYumPlugin(CollectorPlugin):
+class CollectYumPlugin(SerialCollectorPlugin):
     """
     Collector plugin for yum images
     """
