@@ -180,10 +180,8 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
         Store the results for later use
         """
         comp_string = None
-        if comp is not None:
-            comp_purl = PackageURL.from_string(comp.purl)
-            if comp_purl is not None:
-                comp_string = comp_purl.to_string()
+        if comp is not None and PackageURL.from_string(comp.purl) is not None:
+            comp_string = comp.purl
 
         # If needed, create a new list for this method
         # Might need to expand this definition in the future to separate by plug-in
